Install itwinai
============================

In this section, we will run you through the installation and give some instructions for the use of the itwinai framework for HPC and local systems.


.. Include MD files from specific line: https://stackoverflow.com/a/54519037

.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :start-line: 16
